@@ -18,12 +18,15 @@ API 模块用于向外暴露接口，bamboo-engine 的使用者应该永远只
 import logging
 import functools
 import traceback
-from typing import Optional, Any
+from typing import Optional, Any, List
 from contextlib import contextmanager
 
 from .utils.object import Representable
-from .eri import EngineRuntimeInterface
+from .eri import EngineRuntimeInterface, ContextValue
 from .engine import Engine
+from .template import Template
+from .context import Context
+from .utils.constants import VAR_CONTEXT_MAPPING
 
 logger = logging.getLogger("bamboo_engine")
 
@@ -68,6 +71,8 @@ def _ensure_return_api_result(func):
             trace = traceback.format_exc()
             return EngineAPIResult(result=False, message="fail", exc=e, data=None, exc_trace=trace)
 
+        if isinstance(data, EngineAPIResult):
+            return data
         return EngineAPIResult(result=True, message="success", exc=None, data=data, exc_trace=None)
 
     return wrapper
@@ -481,7 +486,7 @@ def get_node_short_histories(runtime: EngineRuntimeInterface, node_id: str, loop
 
 
 @_ensure_return_api_result
-def get_pipeline_debug_info(self, runtime: EngineRuntimeInterface, pipeline_id: str):
+def get_pipeline_debug_info(runtime: EngineRuntimeInterface, pipeline_id: str):
     """
     获取某个流程的调试信息
 
@@ -500,7 +505,7 @@ def get_pipeline_debug_info(self, runtime: EngineRuntimeInterface, pipeline_id:
 
 
 @_ensure_return_api_result
-def get_node_debug_info(self, runtime: EngineRuntimeInterface, node_id: str):
+def get_node_debug_info(runtime: EngineRuntimeInterface, node_id: str):
     """
     获取某个节点的调试信息
 
@@ -532,3 +537,57 @@ def get_node_debug_info(self, runtime: EngineRuntimeInterface, node_id: str):
         "state": state,
         "err": err,
     }
+
+
+@_ensure_return_api_result
+def preview_node_inputs(
+    runtime: EngineRuntimeInterface,
+    pipeline: dict,
+    node_id: str,
+    subprocess_stack: List[str] = [],
+    root_pipeline_data: dict = {},
+    current_constants: dict = {},
+):
+    """
+    预览某个节点的输入结果
+
+    :param pipeline: 预处理后的流程树数据
+    :type  pipeline: dict
+    :param node_id: 节点 ID
+    :type node_id: str
+    :param subprocess_stack: 子流程，需保证顺序
+    :type subprocess_stack: List[str]
+    :param root_pipeline_data: 流程数据
+    :param current_constants: 当前变量
+    :return: 执行结果
+    :rtype: EngineAPIResult
+    """
+    total_constants = {**current_constants, **pipeline["data"].get("inputs", {})}
+    context_values = [
+        ContextValue(
+            key=key,
+            type=VAR_CONTEXT_MAPPING[info["type"]],
+            value=info["value"],
+            code=info.get("custom_type")
+        )
+        for key, info in total_constants.items()
+    ]
+    context = Context(runtime, context_values, root_pipeline_data)
+
+    if subprocess_stack:
+        subprocess = subprocess_stack[0]
+        child_pipeline = pipeline["activities"][subprocess]["pipeline"]
+        param_data = {key: context.variables[key] for key, info in total_constants.items() if info["is_param"]}
+        return preview_node_inputs(
+            runtime=runtime,
+            pipeline=child_pipeline,
+            node_id=node_id,
+            subprocess_stack=subprocess_stack[1:],
+            root_pipeline_data={**root_pipeline_data, **param_data},
+            current_constants=total_constants,
+        )
+    raw_inputs = pipeline["activities"][node_id]["component"]["inputs"]
+    raw_inputs = {key: info["value"] for key, info in raw_inputs.items()}
+    hydrated_context = context.hydrate(deformat=True)
+    inputs = Template(raw_inputs).render(hydrated_context)
+    return inputs
