@@ -485,6 +485,7 @@ class Engine:
                 node = self.runtime.get_node(current_node_id)
                 node_state = self.runtime.get_state_or_none(current_node_id)
                 loop = 1
+                inner_loop = 1
                 reset_mark_bit = False
 
                 if node_state:
@@ -532,6 +533,7 @@ class Engine:
 
                     if node_state.name == states.FINISHED:
                         loop = node_state.loop + 1
+                        inner_loop = node_state.inner_loop + 1
                         reset_mark_bit = True
 
                     # 重入前记录历史
@@ -545,6 +547,7 @@ class Engine:
                     node_id=current_node_id,
                     to_state=states.RUNNING,
                     loop=loop,
+                    inner_loop=inner_loop,
                     root_id=process_info.root_pipeline_id,
                     parent_id=process_info.top_pipeline_id,
                     set_started_time=True,
@@ -565,7 +568,7 @@ class Engine:
                 set_node_info(CurrentNodeInfo(node_id=current_node_id, version=version, loop=loop))
                 type_label = self._get_metrics_node_type(node)
                 execute_start = time.time()
-                execute_result = handler.execute(process_info, loop, version)
+                execute_result = handler.execute(process_info, loop, inner_loop, version)
                 ENGINE_NODE_EXECUTE_TIME.labels(type_label).observe(time.time() - execute_start)
 
                 # 进程是否要进入睡眠
@@ -740,7 +743,7 @@ class Engine:
                     callback_data,
                 )
                 schedule_start = time.time()
-                schedule_result = handler.schedule(process_info, state.loop, schedule, callback_data)
+                schedule_result = handler.schedule(process_info, state.loop, state.inner_loop, schedule, callback_data)
                 ENGINE_NODE_SCHEDULE_TIME.labels(type_label).observe(time.time() - schedule_start)
 
                 if schedule_result.has_next_schedule:
