@@ -35,7 +35,7 @@ from .models import (
 
 # plugin interface
 
-__version__ = "1.0.0"
+__version__ = "2.0.0"
 
 
 def version():
@@ -246,7 +246,12 @@ class EngineAPIHooksMixin:
 
     @abstractmethod
     def pre_prepare_run_pipeline(
-        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, subprocess_context: dict, **options
+        self,
+        pipeline: dict,
+        root_pipeline_data: dict,
+        root_pipeline_context: dict,
+        subprocess_context: dict,
+        **options
     ):
         """
         调用 pre_prepare_run_pipeline 前执行的钩子
@@ -263,7 +268,12 @@ class EngineAPIHooksMixin:
 
     @abstractmethod
     def post_prepare_run_pipeline(
-        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, subprocess_context: dict, **options
+        self,
+        pipeline: dict,
+        root_pipeline_data: dict,
+        root_pipeline_context: dict,
+        subprocess_context: dict,
+        **options
     ):
         """
         调用 pre_prepare_run_pipeline 后执行的钩子
@@ -442,7 +452,9 @@ class EngineAPIHooksMixin:
         """
 
     @abstractmethod
-    def post_forced_fail_activity(self, node_id: str, ex_data: str, old_version: str, new_version: str):
+    def post_forced_fail_activity(
+        self, node_id: str, ex_data: str, old_version: str, new_version: str
+    ):
         """
         强制失败节点后执行的钩子
 
@@ -545,7 +557,9 @@ class TaskMixin:
         """
 
     @abstractmethod
-    def start_timeout_monitor(self, process_id: int, node_id: str, version: str, timeout: int):
+    def start_timeout_monitor(
+        self, process_id: int, node_id: str, version: str, timeout: int
+    ):
         """
         开始对某个节点执行的超时监控，若超时时间归零后节点未进入归档状态，则强制失败该节点
 
@@ -660,7 +674,9 @@ class ProcessMixin:
         """
 
     @abstractmethod
-    def get_process_info_with_root_pipeline(self, pipeline_id: str) -> List[ProcessInfo]:
+    def get_process_info_with_root_pipeline(
+        self, pipeline_id: str
+    ) -> List[ProcessInfo]:
         """
         根据根流程 ID 获取一批进程的信息
 
@@ -680,7 +696,9 @@ class ProcessMixin:
         """
 
     @abstractmethod
-    def get_suspended_process_info(self, suspended_by: str) -> List[SuspendedProcessInfo]:
+    def get_suspended_process_info(
+        self, suspended_by: str
+    ) -> List[SuspendedProcessInfo]:
         """
         获取由于 pipeline 暂停而被暂停执行的进程信息
 
@@ -873,12 +891,31 @@ class StateMixin:
         :rtype: bool
         """
 
+    @abstractmethod
+    def reset_state_inner_loop(self, node_id: str) -> str:
+        """
+        设置节点的当前流程重入次数
+
+        :param node_id: 节点 ID
+        :type node_id: str
+        """
+
+    @abstractmethod
+    def reset_children_state_inner_loop(self, node_id: str):
+        """
+        批量设置子流程节点的所有子节点inner_loop次数
+
+        :param node_id: 子流程节点 ID
+        :type node_id: str
+        """
+
     @abstractmethod
     def set_state(
         self,
         node_id: str,
         to_state: str,
         loop: int = -1,
+        inner_loop: int = -1,
         version: str = None,
         root_id: Optional[str] = None,
         parent_id: Optional[str] = None,
@@ -903,6 +940,8 @@ class StateMixin:
         :type to_state: str
         :param loop: 循环次数, 为 -1 时表示不设置
         :type loop: int, optional
+        :param inner_loop: 当前流程循环次数, 为 -1 时表示不设置
+        :type inner_loop: int, optional
         :param version: 目标状态版本，为空时表示不做版本校验
         :type version: Optional[str], optional
         :param root_id: 根节点 ID，为空时表示不设置
@@ -1006,7 +1045,9 @@ class ScheduleMixin:
         """
 
     @abstractmethod
-    def get_schedule_with_node_and_version(self, node_id: str, version: str) -> Schedule:
+    def get_schedule_with_node_and_version(
+        self, node_id: str, version: str
+    ) -> Schedule:
         """
         通过节点 ID 和执行版本来获取 Scheudle 对象
 
@@ -1098,7 +1139,9 @@ class ContextMixin:
         """
 
     @abstractmethod
-    def upsert_plain_context_values(self, pipeline_id: str, update: Dict[str, ContextValue]):
+    def upsert_plain_context_values(
+        self, pipeline_id: str, update: Dict[str, ContextValue]
+    ):
         """
         更新或创建新的普通上下文数据
 
@@ -1328,7 +1371,9 @@ class ExecutionHistoryMixin:
         """
 
     @abstractmethod
-    def get_short_histories(self, node_id: str, loop: int = -1) -> List[ExecutionShortHistory]:
+    def get_short_histories(
+        self, node_id: str, loop: int = -1
+    ) -> List[ExecutionShortHistory]:
         """
         返回某个节点的简要历史记录
 
@@ -1356,7 +1401,12 @@ class EngineRuntimeInterface(
 ):
     @abstractmethod
     def prepare_run_pipeline(
-        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, subprocess_context: dict, **options
+        self,
+        pipeline: dict,
+        root_pipeline_data: dict,
+        root_pipeline_context: dict,
+        subprocess_context: dict,
+        **options
     ) -> int:
         """
         进行 pipeline 执行前的准备工作，并返回 进程 ID，该函数执行完成后即代表
