@@ -46,7 +46,9 @@ class ServiceActivityHandler(NodeHandler):
     其中所有 set_state 调用都会传入 state version 来确保能够在用户强制失败节点后放弃后续无效的任务执行
     """
 
-    def execute(self, process_info: ProcessInfo, loop: int, version: str) -> ExecuteResult:
+    def execute(
+        self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str
+    ) -> ExecuteResult:
         """
         节点的 execute 处理逻辑
 
@@ -82,7 +84,9 @@ class ServiceActivityHandler(NodeHandler):
             inputs_refs,
         )
 
-        additional_refs = self.runtime.get_context_key_references(pipeline_id=top_pipeline_id, keys=inputs_refs)
+        additional_refs = self.runtime.get_context_key_references(
+            pipeline_id=top_pipeline_id, keys=inputs_refs
+        )
         inputs_refs = inputs_refs.union(additional_refs)
         logger.info(
             "[%s] %s activity final refs: %s",
@@ -92,14 +96,34 @@ class ServiceActivityHandler(NodeHandler):
         )
 
         # prepare context
-        context_values = self.runtime.get_context_values(pipeline_id=top_pipeline_id, keys=inputs_refs)
+        context_values = self.runtime.get_context_values(
+            pipeline_id=top_pipeline_id, keys=inputs_refs
+        )
 
         # pre extract loop outputs
         loop_value = loop + Settings.RERUN_INDEX_OFFSET
         need_render_inputs[self.LOOP_KEY] = loop_value
         if self.LOOP_KEY in data.outputs:
             loop_output_key = data.outputs[self.LOOP_KEY]
-            context_values.append(ContextValue(key=loop_output_key, type=ContextValueType.PLAIN, value=loop_value))
+            context_values.append(
+                ContextValue(
+                    key=loop_output_key, type=ContextValueType.PLAIN, value=loop_value
+                )
+            )
+
+        # pre extract inner_loop outputs
+        inner_loop_value = inner_loop + Settings.RERUN_INDEX_OFFSET
+        need_render_inputs[self.INNER_LOOP_KEY] = inner_loop_value
+        if self.INNER_LOOP_KEY in data.outputs:
+            inner_loop_output_key = data.outputs[self.INNER_LOOP_KEY]
+            context_values.append(
+                ContextValue(
+                    key=inner_loop_output_key,
+                    type=ContextValueType.PLAIN,
+                    value=inner_loop_value,
+                )
+            )
+
         logger.info(
             "[%s] %s activity context values: %s",
             root_pipeline_id,
@@ -125,13 +149,16 @@ class ServiceActivityHandler(NodeHandler):
         root_pipeline_data = ExecutionData(inputs=root_pipeline_inputs, outputs={})
 
         # execute
-        service = self.runtime.get_service(code=self.node.code, version=self.node.version)
+        service = self.runtime.get_service(
+            code=self.node.code, version=self.node.version
+        )
         service.setup_runtime_attributes(
             id=self.node.id,
             version=version,
             top_pipeline_id=top_pipeline_id,
             root_pipeline_id=root_pipeline_id,
             loop=loop,
+            inner_loop=inner_loop
         )
 
         # start monitor
@@ -160,15 +187,24 @@ class ServiceActivityHandler(NodeHandler):
         )
         execute_success = False
         try:
-            service.pre_execute(data=service_data, root_pipeline_data=root_pipeline_data)
-            execute_success = service.execute(data=service_data, root_pipeline_data=root_pipeline_data)
+            service.pre_execute(
+                data=service_data, root_pipeline_data=root_pipeline_data
+            )
+            execute_success = service.execute(
+                data=service_data, root_pipeline_data=root_pipeline_data
+            )
         except Exception:
             ex_data = traceback.format_exc()
             service_data.outputs.ex_data = ex_data
-            logger.warning("[%s]service execute fail: %s", process_info.root_pipeline_id, ex_data)
-        logger.debug("[%s] service data after execute: %s", root_pipeline_id, service_data)
+            logger.warning(
+                "[%s]service execute fail: %s", process_info.root_pipeline_id, ex_data
+            )
+        logger.debug(
+            "[%s] service data after execute: %s", root_pipeline_id, service_data
+        )
         service_data.outputs._result = execute_success
         service_data.outputs._loop = loop
+        service_data.outputs._inner_loop = inner_loop
 
         # execute success
         if execute_success:
@@ -317,6 +353,7 @@ class ServiceActivityHandler(NodeHandler):
         self,
         process_info: ProcessInfo,
         loop: int,
+        inner_loop: int,
         schedule: Schedule,
         callback_data: Optional[CallbackData] = None,
     ) -> ScheduleResult:
@@ -350,13 +387,16 @@ class ServiceActivityHandler(NodeHandler):
         )
 
         # schedule
-        service = self.runtime.get_service(code=self.node.code, version=self.node.version)
+        service = self.runtime.get_service(
+            code=self.node.code, version=self.node.version
+        )
         service.setup_runtime_attributes(
             id=self.node.id,
             version=schedule.version,
             top_pipeline_id=top_pipeline_id,
             root_pipeline_id=root_pipeline_id,
             loop=loop,
+            inner_loop=inner_loop,
         )
 
         schedule_success = False
@@ -373,6 +413,8 @@ class ServiceActivityHandler(NodeHandler):
 
         service_data.outputs._result = schedule_success
         service_data.outputs._loop = loop
+        service_data.outputs._inner_loop = inner_loop
+
         self.runtime.add_schedule_times(schedule.id)
         self.runtime.set_execution_data(node_id=self.node.id, data=service_data)
 
